@@ -1,6 +1,6 @@
-from qcodes import VisaInstrument
-from qcodes import Instrument
-from qcodes.instrument.channel import InstrumentChannel
+from typing import Any, Dict, Optional
+
+from qcodes.instrument import Instrument, InstrumentChannel, VisaInstrument
 
 
 class B2962AChannel(InstrumentChannel):
@@ -10,10 +10,9 @@ class B2962AChannel(InstrumentChannel):
     def __init__(self, parent: Instrument, name: str, chan: int) -> None:
         """
         Args:
-            parent (Instrument): The instrument to which the channel is
-            attached.
-            name (str): The name of the channel
-            channum (int): The number of the channel in question (1-2)
+            parent: The instrument to which the channel is attached.
+            name: The name of the channel
+            chan: The number of the channel in question (1-2)
         """
         # Sanity Check inputs
         if name not in ['ch1', 'ch2']:
@@ -95,7 +94,7 @@ class B2962A(VisaInstrument):
         - Similar drivers have special handlers to map return values of
           9.9e+37 to inf, is this needed?
     """
-    def __init__(self, name, address, **kwargs):
+    def __init__(self, name: str, address: str, **kwargs: Any):
         super().__init__(name, address, terminator='\n', **kwargs)
 
         # The B2962A supports two channels
@@ -106,9 +105,10 @@ class B2962A(VisaInstrument):
 
         self.connect_message()
 
-    def get_idn(self):
-        IDN = self.ask_raw('*IDN?')
-        vendor, model, serial, firmware = map(str.strip, IDN.split(','))
-        IDN = {'vendor': vendor, 'model': model,
-               'serial': serial, 'firmware': firmware}
+    def get_idn(self) -> Dict[str, Optional[str]]:
+        IDN_str = self.ask_raw('*IDN?')
+        vendor, model, serial, firmware = map(str.strip, IDN_str.split(','))
+        IDN: Dict[str, Optional[str]] = {
+            'vendor': vendor, 'model': model,
+            'serial': serial, 'firmware': firmware}
         return IDN
