@@ -1,17 +1,19 @@
-from distutils.version import LooseVersion
 from typing import Any, Sequence, Tuple, Union, cast
 
+from packaging import version
 from pyvisa.errors import VisaIOError
 
-from qcodes import InstrumentChannel, VisaInstrument
-from qcodes.instrument.group_parameter import Group, GroupParameter
-from qcodes.instrument.parameter import (
+from qcodes.instrument import InstrumentChannel, VisaInstrument
+from qcodes.parameters import (
+    Group,
+    GroupParameter,
     ManualParameter,
     MultiParameter,
     ParamRawDataType,
+    create_on_off_val_mapping,
 )
-from qcodes.utils.helpers import create_on_off_val_mapping
-from qcodes.utils.validators import Bool, Enum, Ints, Numbers
+from qcodes.utils import convert_legacy_version_to_supported_version
+from qcodes.validators import Bool, Enum, Ints, Numbers
 
 
 class MeasurementPair(MultiParameter):
@@ -194,9 +196,9 @@ class KeysightE4980A(VisaInstrument):
 
         idn = self.IDN.get()
 
-        self.has_firmware_a_02_10_or_above = (
-                LooseVersion(idn["firmware"]) >= LooseVersion("A.02.10")
-        )
+        self.has_firmware_a_02_10_or_above = version.parse(
+            convert_legacy_version_to_supported_version(idn["firmware"])
+        ) >= version.parse(convert_legacy_version_to_supported_version("A.02.10"))
 
         self.has_option_001 = '001' in self._options()
         self._dc_bias_v_level_range: Union[Numbers, Enum]
