@@ -5,7 +5,6 @@ from typing import (
     Any,
     Dict,
     List,
-    Literal,
     Optional,
     Sequence,
     Tuple,
@@ -15,7 +14,7 @@ from typing import (
 )
 
 import numpy as np
-from typing_extensions import TypedDict
+from typing_extensions import Literal, TypedDict
 
 import qcodes.validators as vals
 from qcodes.instrument import InstrumentChannel
