@@ -1,4 +1,6 @@
-from typing import Protocol, Tuple
+from typing import Tuple
+
+from typing_extensions import Protocol
 
 from qcodes.instrument.base import InstrumentProtocol
 
