@@ -1,8 +1,7 @@
 from typing import Dict, Optional
 
-from qcodes import IPInstrument
-from qcodes.instrument.channel import ChannelList, InstrumentChannel
-from qcodes.utils import validators as vals
+from qcodes import validators as vals
+from qcodes.instrument import ChannelList, InstrumentChannel, IPInstrument
 
 
 class MC_channel(InstrumentChannel):
