@@ -1,3 +1,5 @@
 # Ensuring backwards compatibility
 
-from .ZNB import ZNB as ZNB20
+from .ZNB import ZNB
+
+ZNB20 = ZNB
