@@ -1,20 +1,18 @@
 import datetime as dt
-import time
-import struct
 import io
-import zipfile as zf
 import logging
-from functools import partial
-from typing import List, Sequence, Dict, Union, Optional, Any
+import struct
 import time
-
 import xml.etree.ElementTree as ET
-import numpy as np
+import zipfile as zf
+from functools import partial
+from typing import Any, Dict, List, Optional, Sequence, Union
 
-from qcodes import Instrument, VisaInstrument, validators as vals
-from qcodes.instrument.channel import InstrumentChannel, ChannelList
-from qcodes.utils.validators import Validator
-from broadbean.sequence import fs_schema, InvalidForgedSequenceError
+import numpy as np
+from broadbean.sequence import InvalidForgedSequenceError, fs_schema
+
+from qcodes import validators as vals
+from qcodes.instrument import ChannelList, Instrument, InstrumentChannel, VisaInstrument
 
 log = logging.getLogger(__name__)
 
@@ -49,18 +47,28 @@ _fg_path_val_map = {'5208': {'DC High BW': "DCHB",
                                'DCamplified': 'DCAM',
                                'AC': 'AC'},
                     '70002A': {'direct': 'DIR',
+                               'DCamplified': 'DCAM',
+                               'AC': 'AC'},
+                    '70001B': {'direct': 'DIR',
+                               'DCamplified': 'DCAM',
+                               'AC': 'AC'},
+                    '70002B': {'direct': 'DIR',
                                'DCamplified': 'DCAM',
                                'AC': 'AC'}}
 
 # number of markers per channel
 _num_of_markers_map = {'5208': 4,
                        '70001A': 2,
-                       '70002A': 2}
+                       '70002A': 2,
+                       '70001B': 2,
+                       '70002B': 2}
 
 # channel resolution
 _chan_resolutions = {'5208': [12, 13, 14, 15, 16],
                      '70001A': [8, 9, 10],
-                     '70002A': [8, 9, 10]}
+                     '70002A': [8, 9, 10],
+                     '70001B': [8, 9, 10],
+                     '70002B': [8, 9, 10]}
 
 # channel resolution docstrings
 _chan_resolution_docstrings = {'5208': "12 bit resolution allows for four "
@@ -72,6 +80,14 @@ _chan_resolution_docstrings = {'5208': "12 bit resolution allows for four "
                                          "allows for one, and 10 bit "
                                          "does NOT allow for markers ",
                                '70002A': "8 bit resolution allows for two "
+                                         "markers, 9 bit resolution "
+                                         "allows for one, and 10 bit "
+                                         "does NOT allow for markers ",
+                               '70001B': "8 bit resolution allows for two "
+                                         "markers, 9 bit resolution "
+                                         "allows for one, and 10 bit "
+                                         "does NOT allow for markers ",
+                               '70002B': "8 bit resolution allows for two "
                                          "markers, 9 bit resolution "
                                          "allows for one, and 10 bit "
                                          "does NOT allow for markers "}
@@ -79,18 +95,24 @@ _chan_resolution_docstrings = {'5208': "12 bit resolution allows for four "
 # channel amplitudes
 _chan_amps = {'70001A': 0.5,
               '70002A': 0.5,
+              '70001B': 0.5,
+              '70002B': 0.5,
               '5208': 1.5}
 
 # marker ranges
 _marker_high = {'70001A': (-1.4, 1.4),
                 '70002A': (-1.4, 1.4),
+                '70001B': (-1.4, 1.4),
+                '70002B': (-1.4, 1.4),
                 '5208': (-0.5, 1.75)}
 _marker_low = {'70001A': (-1.4, 1.4),
                '70002A': (-1.4, 1.4),
+               '70001B': (-1.4, 1.4),
+               '70002B': (-1.4, 1.4),
                '5208': (-0.3, 1.55)}
 
 
-class SRValidator(Validator):
+class SRValidator(vals.Validator[float]):
     """
     Validator to validate the AWG clock sample rate
     """
@@ -102,10 +124,10 @@ class SRValidator(Validator):
                 rate validation depends on many clock settings
         """
         self.awg = awg
-        if self.awg.model == '70001A':
+        if self.awg.model in ['70001A', '70001B']:
             self._internal_validator = vals.Numbers(1.49e3, 50e9)
             self._freq_multiplier = 4
-        elif self.awg.model == '70002A':
+        elif self.awg.model in ['70002A', '70002B']:
             self._internal_validator = vals.Numbers(1.49e3, 25e9)
             self._freq_multiplier = 2
         elif self.awg.model == '5208':
@@ -124,7 +146,7 @@ class SRValidator(Validator):
             validator.validate(value)
 
 
-class AWGChannel(InstrumentChannel):
+class Tektronix70000AWGChannel(InstrumentChannel):
     """
     Class to hold a channel of the AWG.
     """
@@ -363,16 +385,28 @@ class AWGChannel(InstrumentChannel):
                                    f', {tracknr}')
 
 
+AWGChannel = Tektronix70000AWGChannel
+"""
+Alias for Tektronix70000AWGChannel for backwards compatibility.
+"""
+
+
 class AWG70000A(VisaInstrument):
     """
     The QCoDeS driver for Tektronix AWG70000A series AWG's.
 
-    The drivers for AWG70001A and AWG70002A should be subclasses of this
-    general class.
+    The drivers for AWG70001A/AWG70001B and AWG70002A/AWG70002B should be
+    subclasses of this general class.
     """
 
-    def __init__(self, name: str, address: str, num_channels: int,
-                 timeout: float=10, **kwargs: Any) -> None:
+    def __init__(
+        self,
+        name: str,
+        address: str,
+        num_channels: int,
+        timeout: float = 10,
+        **kwargs: Any,
+    ) -> None:
         """
         Args:
             name: The name used internally by QCoDeS in the DataSet
@@ -389,10 +423,11 @@ class AWG70000A(VisaInstrument):
         # The 'model' value begins with 'AWG'
         self.model = self.IDN()['model'][3:]
 
-        if self.model not in ['70001A', '70002A', '5208']:
-            raise ValueError('Unknown model type: {}. Are you using '
-                             'the right driver for your instrument?'
-                             ''.format(self.model))
+        if self.model not in ["70001A", "70002A", "70001B", "70002B", "5208"]:
+            raise ValueError(
+                f"Unknown model type: {self.model}. Are you using "
+                f"the right driver for your instrument?"
+            )
 
         self.add_parameter('current_directory',
                            label='Current file system directory',
@@ -443,19 +478,19 @@ class AWG70000A(VisaInstrument):
 
         # We deem 2 channels too few for a channel list
         if self.num_channels > 2:
-            chanlist = ChannelList(self, 'Channels', AWGChannel,
-                                   snapshotable=False)
+            chanlist = ChannelList(
+                self, "Channels", Tektronix70000AWGChannel, snapshotable=False
+            )
 
         for ch_num in range(1, num_channels+1):
             ch_name = f'ch{ch_num}'
-            channel = AWGChannel(self, ch_name, ch_num)
+            channel = Tektronix70000AWGChannel(self, ch_name, ch_num)
             self.add_submodule(ch_name, channel)
             if self.num_channels > 2:
                 chanlist.append(channel)
 
         if self.num_channels > 2:
-            chanlist.lock()
-            self.add_submodule('channels', chanlist)
+            self.add_submodule("channels", chanlist.to_channel_tuple())
 
         # Folder on the AWG where to files are uplaoded by default
         self.wfmxFileFolder = "\\Users\\OEM\\Documents"
@@ -871,11 +906,11 @@ class AWG70000A(VisaInstrument):
 
     @staticmethod
     def make_SEQX_from_forged_sequence(
-            seq: Dict[int, Dict],
+            seq: Dict[int, Dict[Any, Any]],
             amplitudes: List[float],
             seqname: str,
-            channel_mapping: Optional[Dict[Union[str, int],
-                                           int]]=None) -> bytes:
+            channel_mapping: Optional[Dict[Union[str, int], int]] = None
+    ) -> bytes:
         """
         Make a .seqx from a forged broadbean sequence.
         Supports subsequences.
@@ -1071,7 +1106,9 @@ class AWG70000A(VisaInstrument):
                      go_to: Sequence[int],
                      wfms: Sequence[Sequence[np.ndarray]],
                      amplitudes: Sequence[float],
-                     seqname: str) -> bytes:
+                     seqname: str,
+                     flags: Optional[Sequence[Sequence[Sequence[int]]]] = None
+                     ) -> bytes:
         """
         Make a full .seqx file (bundle)
         A .seqx file can presumably hold several sequences, but for now
@@ -1110,6 +1147,11 @@ class AWG70000A(VisaInstrument):
                 a list [ch1_amp, ch2_amp].
             seqname: The name of the sequence. This name will appear in the
                 sequence list. Note that all spaces are converted to '_'
+            flags: Flags for the auxiliary outputs. 0 for 'No change', 1 for
+                'High', 2 for 'Low', 3 for 'Toggle', or 4 for 'Pulse'. 4 flags
+                [A, B, C, D] for every channel in every element, packed like:
+                [[ch1pos1, ch1pos2, ...], [ch2pos1, ...], ...]
+                If omitted, no flags will be set.
 
         Returns:
             The binary .seqx file, ready to be sent to the instrument.
@@ -1136,7 +1178,7 @@ class AWG70000A(VisaInstrument):
                                           event_jumps, event_jump_to,
                                           go_to, wfm_names,
                                           seqname,
-                                          chans)
+                                          chans, flags=flags)
 
         user_file = b''
         setup_file = AWG70000A._makeSetupFile(seqname)
@@ -1199,7 +1241,9 @@ class AWG70000A(VisaInstrument):
                      elem_names: Sequence[Sequence[str]],
                      seqname: str,
                      chans: int,
-                     subseq_positions: Sequence[int] = ()) -> str:
+                     subseq_positions: Sequence[int] = (),
+                     flags: Optional[Sequence[Sequence[Sequence[int]]]] = None
+                     ) -> str:
         """
         Make an xml file describing a sequence.
 
@@ -1226,6 +1270,11 @@ class AWG70000A(VisaInstrument):
                 up front.
             subseq_positions: The positions (step numbers) occupied by
                 subsequences
+            flags: Flags for the auxiliary outputs. 0 for 'No change', 1 for
+                'High', 2 for 'Low', 3 for 'Toggle', or 4 for 'Pulse'. 4 flags
+                [A, B, C, D] for every channel in every element, packed like:
+                [[ch1pos1, ch1pos2, ...], [ch2pos1, ...], ...]
+                If omitted, no flags will be set.
 
         Returns:
             A str containing the file contents, to be saved as an .sml file
@@ -1235,6 +1284,7 @@ class AWG70000A(VisaInstrument):
 
         waitinputs = {0: 'None', 1: 'TrigA', 2: 'TrigB', 3: 'Internal'}
         eventinputs = {0: 'None', 1: 'TrigA', 2: 'TrigB', 3: 'Internal'}
+        flaginputs = {0:'NoChange', 1:'High', 2:'Low', 3:'Toggle', 4:'Pulse'}
 
         inputlsts = [trig_waits, nreps, event_jump_to, go_to]
         lstlens = [len(lst) for lst in inputlsts]
@@ -1308,8 +1358,8 @@ class AWG70000A(VisaInstrument):
                 rep.text = 'Once'
                 repcount.text = '1'
             else:
-                rep.text = 'RepeatCount'
-                repcount.text = '{:d}'.format(nreps[n-1])
+                rep.text = "RepeatCount"
+                repcount.text = f"{nreps[n-1]:d}"
             # trigger wait
             temp_elem = ET.SubElement(step, 'WaitInput')
             temp_elem.text = waitinputs[trig_waits[n-1]]
@@ -1322,8 +1372,8 @@ class AWG70000A(VisaInstrument):
                 jumpto.text = 'Next'
                 jumpstep.text = '1'
             else:
-                jumpto.text = 'StepIndex'
-                jumpstep.text = '{:d}'.format(event_jump_to[n-1])
+                jumpto.text = "StepIndex"
+                jumpstep.text = f"{event_jump_to[n-1]:d}"
             # Go to
             goto = ET.SubElement(step, 'GoTo')
             gotostep = ET.SubElement(step, 'GoToStep')
@@ -1331,8 +1381,8 @@ class AWG70000A(VisaInstrument):
                 goto.text = 'Next'
                 gotostep.text = '1'
             else:
-                goto.text = 'StepIndex'
-                gotostep.text = '{:d}'.format(go_to[n-1])
+                goto.text = "StepIndex"
+                gotostep.text = f"{go_to[n-1]:d}"
 
             assets = ET.SubElement(step, 'Assets')
             for assetname in elem_names[n-1]:
@@ -1345,13 +1395,18 @@ class AWG70000A(VisaInstrument):
                 else:
                     temp_elem.text = 'Waveform'
 
-            flags = ET.SubElement(step, 'Flags')
-            for _ in range(chans):
-                flagset = ET.SubElement(flags, 'FlagSet')
-                for flg in ['A', 'B', 'C', 'D']:
+            # convert flag settings to strings
+            flags_list = ET.SubElement(step, 'Flags')
+            for chan in range(chans):
+                flagset = ET.SubElement(flags_list, 'FlagSet')
+                for flgind, flg in enumerate(['A', 'B', 'C', 'D']):
                     temp_elem = ET.SubElement(flagset, 'Flag')
                     temp_elem.set('name', flg)
-                    temp_elem.text = 'NoChange'
+                    if flags is None:
+                        # no flags were passed to the function
+                        temp_elem.text = 'NoChange'
+                    else:
+                        temp_elem.text = flaginputs[flags[chan][n-1][flgind]]
 
         temp_elem = ET.SubElement(datasets, 'ProductSpecific')
         temp_elem.set('name', '')
