@@ -1,18 +1,17 @@
 """
 This module defines a number of functions to make it easier to
 work with log messages from QCoDeS. Specifically it enables
-exports of logs and log files to a :class:`pd.DataFrame`
+exports of logs and log files to a :class:`pandas.DataFrame`
 
 """
-from __future__ import annotations
 
 import io
 import logging
 from contextlib import contextmanager
-from typing import TYPE_CHECKING, Callable, Iterator, Sequence
+from typing import Callable, Iterator, Optional, Sequence, Tuple
 
-if TYPE_CHECKING:
-    import pandas as pd
+import pandas
+from pandas.core.series import Series
 
 from .logger import (
     FORMAT_STRING_DICT,
@@ -23,13 +22,11 @@ from .logger import (
 )
 
 
-def log_to_dataframe(
-    log: Sequence[str],
-    columns: Sequence[str] | None = None,
-    separator: str | None = None,
-) -> pd.DataFrame:
+def log_to_dataframe(log: Sequence[str],
+                     columns: Optional[Sequence[str]] = None,
+                     separator: Optional[str] = None) -> pandas.DataFrame:
     """
-    Return the provided or default log string as a :class:`pd.DataFrame`.
+    Return the provided or default log string as a :class:`pandas.DataFrame`.
 
     Unless :data:`qcodes.logger.logger.LOGGING_SEPARATOR` or
     :data:`qcodes.logger.logger.FORMAT_STRING_DICT` have been changed using the
@@ -49,10 +46,8 @@ def log_to_dataframe(
             :func:`qcodes.logger.logger.start_logger`.
 
     Returns:
-        A :class:`pd.DataFrame` containing the log content.
+        A :class:`pandas.DataFrame` containing the log content.
     """
-    import pandas as pd  # pylint: disable=import-outside-toplevel
-
     separator = separator or LOGGING_SEPARATOR
     columns = columns or list(FORMAT_STRING_DICT.keys())
     # note: if we used commas as separators, pandas read_csv
@@ -60,18 +55,16 @@ def log_to_dataframe(
 
     split_cont = [line.split(separator) for line in log
                   if line[0].isdigit()]  # avoid tracebacks
-    dataframe = pd.DataFrame(split_cont, columns=list(columns))
+    dataframe = pandas.DataFrame(split_cont, columns=list(columns))
 
     return dataframe
 
 
-def logfile_to_dataframe(
-    logfile: str | None = None,
-    columns: Sequence[str] | None = None,
-    separator: str | None = None,
-) -> pd.DataFrame:
+def logfile_to_dataframe(logfile: Optional[str] = None,
+                         columns: Optional[Sequence[str]] = None,
+                         separator: Optional[str] = None) -> pandas.DataFrame:
     """
-    Return the provided or default logfile as a :class:`pd.DataFrame`.
+    Return the provided or default logfile as a :class:`pandas.DataFrame`.
 
     Unless :data:`qcodes.logger.logger.LOGGING_SEPARATOR` or
     :data:`qcodes.logger.logger.FORMAT_STRING_DICT` have been changed using
@@ -92,7 +85,7 @@ def logfile_to_dataframe(
 
 
     Returns:
-        A :class:`pd.DataFrame` containing the logfile content.
+        A :class:`pandas.DataFrame` containing the logfile content.
     """
     logfile = logfile or get_log_file_name()
     with open(logfile) as f:
@@ -101,9 +94,9 @@ def logfile_to_dataframe(
     return log_to_dataframe(raw_cont, columns, separator)
 
 
-def time_difference(
-    firsttimes: pd.Series, secondtimes: pd.Series, use_first_series_labels: bool = True
-) -> pd.Series:
+def time_difference(firsttimes: Series,
+                    secondtimes: Series,
+                    use_first_series_labels: bool = True) -> Series:
     """
     Calculate the time differences between two series
     containing time stamp strings as their values.
@@ -116,10 +109,8 @@ def time_difference(
             the labels of secondtimes
 
     Returns:
-        A :class:`pd.Series`  with float values of the time difference (s)
+        A :class:`pandas.Series`  with float values of the time difference (s)
     """
-    import pandas as pd  # pylint: disable=import-outside-toplevel
-
 
     if ',' in firsttimes.iloc[0]:
         nfirsttimes = firsttimes.str.replace(',', '.')
@@ -136,19 +127,19 @@ def time_difference(
     timedeltas = (t1s.to_numpy() - t0s.to_numpy()).astype("float") * 1e-9
 
     if use_first_series_labels:
-        output = pd.Series(timedeltas, index=nfirsttimes.index)
+        output = pandas.Series(timedeltas, index=nfirsttimes.index)
     else:
-        output = pd.Series(timedeltas, index=nsecondtimes.index)
+        output = pandas.Series(timedeltas, index=nsecondtimes.index)
 
     return output
 
 
 @contextmanager
-def capture_dataframe(
-    level: LevelType = logging.DEBUG, logger: logging.Logger | None = None
-) -> Iterator[tuple[logging.StreamHandler, Callable[[], pd.DataFrame]]]:
+def capture_dataframe(level: LevelType = logging.DEBUG,
+                      logger: Optional[logging.Logger] = None) -> \
+        Iterator[Tuple[logging.StreamHandler, Callable[[], pandas.DataFrame]]]:
     """
-    Context manager to capture the logs in a :class:`pd.DataFrame`
+    Context manager to capture the logs in a :class:`pandas.DataFrame`
 
     Example:
         >>> with logger.capture_dataframe() as (handler, cb):
@@ -162,7 +153,7 @@ def capture_dataframe(
 
     Returns:
         Tuple of handler that is used to capture the log messages and callback
-        that returns the cumulative :class:`pd.DataFrame` at any given
+        that returns the cumulative :class:`pandas.DataFrame` at any given
         point (within the context)
     """
     # get root logger if none is specified.
