@@ -39,23 +39,54 @@ Supported commands to .each are:
     - Task: any callable that does not generate data
     - Wait: a delay
 """
-from typing import Optional, Sequence
-from datetime import datetime
 import logging
 import time
+from datetime import datetime
+from typing import Dict, Optional, Sequence
+
 import numpy as np
 
-from qcodes.station import Station
-from qcodes.data.data_set import new_data
 from qcodes.data.data_array import DataArray
-from qcodes.utils.helpers import wait_secs, full_class, tprint
-from qcodes.utils.metadata import Metadatable
+from qcodes.data.data_set import new_data
+from qcodes.metadatable import Metadatable
+from qcodes.station import Station
+from qcodes.utils import full_class
 
-from .actions import (_actions_snapshot, Task, Wait, _Measure, _Nest,
-                      BreakIf, _QcodesBreak)
+from .actions import (
+    BreakIf,
+    Task,
+    Wait,
+    _actions_snapshot,
+    _Measure,
+    _Nest,
+    _QcodesBreak,
+)
 
 log = logging.getLogger(__name__)
 
+_tprint_times: Dict[str, float] = {}
+
+
+def wait_secs(finish_clock: float) -> float:
+    """
+    Calculate the number of seconds until a given clock time.
+    The clock time should be the result of ``time.perf_counter()``.
+    Does NOT wait for this time.
+    """
+    delay = finish_clock - time.perf_counter()
+    if delay < 0:
+        logging.warning(f"negative delay {delay:.6f} sec")
+        return 0
+    return delay
+
+
+def tprint(string: str, dt: int = 1, tag: str = "default") -> None:
+    """Print progress of a loop every ``dt`` seconds."""
+    ptime = _tprint_times.get(tag, 0)
+    if (time.time() - ptime) > dt:
+        print(string)
+        _tprint_times[tag] = time.time()
+
 
 def active_loop():
     return ActiveLoop.active_loop
@@ -95,7 +126,7 @@ class Loop(Metadatable):
                  progress_interval=None):
         super().__init__()
         if delay < 0:
-            raise ValueError('delay must be > 0, not {}'.format(repr(delay)))
+            raise ValueError(f"delay must be > 0, not {repr(delay)}")
 
         self.sweep_values = sweep_values
         self.delay = delay
@@ -257,7 +288,7 @@ class Loop(Metadatable):
                       params_to_skip_update: Optional[Sequence[str]] = None):
         """
         State of the loop as a JSON-compatible dict (everything that
-        the custom JSON encoder class :class:'qcodes.utils.helpers.NumpyJSONEncoder'
+        the custom JSON encoder class :class:'.NumpyJSONEncoder'
         supports).
 
         Args:
