@@ -1,7 +1,9 @@
 from __future__ import annotations
 
 from collections.abc import Callable
-from typing import Any, Generic, Literal, TypeVar
+from typing import Any, Generic, TypeVar
+
+from typing_extensions import Literal
 
 from qcodes.utils import is_function
 
