@@ -5,7 +5,9 @@ from __future__ import annotations
 
 import logging
 import os
-from typing import TYPE_CHECKING, Any, Callable, Literal
+from typing import TYPE_CHECKING, Any, Callable
+
+from typing_extensions import Literal
 
 from .command import Command
 from .parameter_base import ParamDataType, ParameterBase
