@@ -1,3 +1,4 @@
+import sys
 import time
 from math import floor
 
@@ -5,6 +6,7 @@ import pytest
 
 from qcodes.dataset.data_set import (
     DataSet,
+    get_guids_by_run_spec,
     load_by_counter,
     load_by_guid,
     load_by_id,
@@ -20,9 +22,13 @@ from qcodes.dataset.sqlite.queries import (
     get_raw_run_attributes,
     raw_time_to_str_time,
 )
+from qcodes.utils import QCoDeSDeprecationWarning
 
 
 @pytest.mark.usefixtures("experiment")
+@pytest.mark.xfail(
+    condition=sys.platform == "win32", reason="Time resolution is too low on windows"
+)
 def test_load_by_id():
     ds = new_data_set("test-dataset")
     run_id = ds.run_id
@@ -54,6 +60,21 @@ def test_load_by_id():
         _ = load_by_id(non_existing_run_id)
 
 
+@pytest.mark.usefixtures("experiment")
+def test_get_guids_from_run_spec_warns():
+    ds = new_data_set("test-dataset")
+    run_id = ds.run_id
+    ds.mark_started()
+    ds.mark_completed()
+    expected_guid = ds.guid
+    with pytest.warns(
+        expected_warning=QCoDeSDeprecationWarning, match="Unused part of private api"
+    ):
+        loaded_guids = get_guids_from_run_spec(captured_run_id=run_id, conn=ds.conn)
+    assert len(loaded_guids) == 1
+    assert loaded_guids[0] == expected_guid
+
+
 @pytest.mark.usefixtures("empty_temp_db")
 def test_load_by_counter():
     exp = new_experiment(name="for_loading", sample_name="no_sample")
@@ -262,7 +283,7 @@ def test_load_by_run_spec(empty_temp_db, some_interdeps):
 
     conn = created_ds[0].conn
 
-    guids = get_guids_from_run_spec(conn=conn)
+    guids = get_guids_by_run_spec(conn=conn)
     assert len(guids) == 3
 
     # since we are not copying runs from multiple dbs we can always load by
@@ -275,24 +296,24 @@ def test_load_by_run_spec(empty_temp_db, some_interdeps):
 
     # All the datasets datasets have the same captured counter
     # so we cannot load by that alone
-    guids_cc1 = get_guids_from_run_spec(captured_counter=1, conn=conn)
+    guids_cc1 = get_guids_by_run_spec(captured_counter=1, conn=conn)
     assert len(guids_cc1) == 3
     with pytest.raises(NameError, match="More than one matching"):
         load_by_run_spec(captured_counter=1)
 
     # there are two different experiments with exp name "test-experiment1"
     # and thus 2 different datasets with counter=1 and that exp name
-    guids_cc1_te1 = get_guids_from_run_spec(captured_counter=1,
-                                            experiment_name='te1',
-                                            conn=conn)
+    guids_cc1_te1 = get_guids_by_run_spec(
+        captured_counter=1, experiment_name="te1", conn=conn
+    )
     assert len(guids_cc1_te1) == 2
     with pytest.raises(NameError, match="More than one matching"):
         load_by_run_spec(captured_counter=1, experiment_name="te1", conn=conn)
 
     # but for "test-experiment2" there is only one
-    guids_cc1_te2 = get_guids_from_run_spec(captured_counter=1,
-                                            experiment_name='te2',
-                                            conn=conn)
+    guids_cc1_te2 = get_guids_by_run_spec(
+        captured_counter=1, experiment_name="te2", conn=conn
+    )
     assert len(guids_cc1_te2) == 1
     loaded_ds = load_by_run_spec(captured_counter=1,
                                  experiment_name="te2",
@@ -302,9 +323,9 @@ def test_load_by_run_spec(empty_temp_db, some_interdeps):
 
     # there are two different experiments with sample name "test_sample2" but
     # different exp names so the counter is not unique
-    guids_cc1_ts2 = get_guids_from_run_spec(captured_counter=1,
-                                            sample_name='ts2',
-                                            conn=conn)
+    guids_cc1_ts2 = get_guids_by_run_spec(
+        captured_counter=1, sample_name="ts2", conn=conn
+    )
     assert len(guids_cc1_ts2) == 2
     with pytest.raises(NameError, match="More than one matching"):
         load_by_run_spec(captured_counter=1,
@@ -312,9 +333,9 @@ def test_load_by_run_spec(empty_temp_db, some_interdeps):
                          conn=conn)
 
     # but for  "test_sample1" there is only one
-    guids_cc1_ts1 = get_guids_from_run_spec(captured_counter=1,
-                                            sample_name='ts1',
-                                            conn=conn)
+    guids_cc1_ts1 = get_guids_by_run_spec(
+        captured_counter=1, sample_name="ts1", conn=conn
+    )
     assert len(guids_cc1_ts1) == 1
     loaded_ds = load_by_run_spec(captured_counter=1,
                                  sample_name="ts1",
@@ -335,6 +356,5 @@ def test_load_by_run_spec(empty_temp_db, some_interdeps):
     with pytest.raises(NameError, match="No run matching"):
         load_by_run_spec(captured_counter=10000, sample_name="ts2", conn=conn)
 
-    empty_guid_list = get_guids_from_run_spec(conn=conn,
-                                              experiment_name='nosuchexp')
+    empty_guid_list = get_guids_by_run_spec(conn=conn, experiment_name="nosuchexp")
     assert empty_guid_list == []
