@@ -7,7 +7,6 @@ import qcodes.measure
 from qcodes.data.data_set import load_data
 from qcodes.data.gnuplot_format import GNUPlotFormat
 from qcodes.data.hdf5_format import HDF5Format, HDF5FormatMetadata
-from qcodes.parameters import Parameter
 from qcodes.tests.legacy.data_mocks import DataSet2D
 
 
@@ -43,11 +42,10 @@ class TestNoSorting(TestCase):
     formatter, so I guess it goes here.
     """
 
-    param = Parameter(
-        name="mixed_val_mapping_param",
-        get_cmd=lambda: np.random.randint(1, 3),
-        val_mapping={1: 1, "2": 2},
-    )
+    param = qcodes.Parameter(name='mixed_val_mapping_param',
+                             get_cmd=lambda: np.random.randint(1, 3),
+                             val_mapping={1: 1, '2': 2}
+                             )
 
     def test_can_measure(self):
         qcodes.measure.Measure(self.param).run(name="test_no_sorting")
