@@ -2,7 +2,8 @@ import math
 
 import numpy as np
 import pytest
-from qcodes.utils.validators import Bool
+
+from qcodes.validators import Bool
 
 from .conftest import AClass, a_func
 
